@@ -126,9 +126,9 @@ PyObject *_ped_Alignment_get(_ped_Alignment *self, void *closure) {
     }
 
     if (!strcmp(member, "offset")) {
-        return PyLong_FromLong(self->offset);
+        return PyLong_FromLongLong(self->offset);
     } else if (!strcmp(member, "grain_size")) {
-        return PyLong_FromLong(self->grain_size);
+        return PyLong_FromLongLong(self->grain_size);
     } else {
         PyErr_Format(PyExc_AttributeError, "_ped.Alignment object has no attribute %s", member);
         return NULL;
@@ -143,12 +143,12 @@ int _ped_Alignment_set(_ped_Alignment *self, PyObject *value, void *closure) {
     }
 
     if (!strcmp(member, "offset")) {
-        self->offset = PyLong_AsLong(value);
+        self->offset = PyLong_AsLongLong(value);
         if (PyErr_Occurred()) {
             return -1;
         }
     } else if (!strcmp(member, "grain_size")) {
-        self->grain_size = PyLong_AsLong(value);
+        self->grain_size = PyLong_AsLongLong(value);
         if (PyErr_Occurred()) {
             return -1;
         }
@@ -252,7 +252,7 @@ PyObject *py_ped_alignment_align_up(PyObject *s, PyObject *args) {
         return NULL;
     }
 
-    return PyLong_FromLong(ret);
+    return PyLong_FromLongLong(ret);
 }
 
 PyObject *py_ped_alignment_align_down(PyObject *s, PyObject *args) {
@@ -284,7 +284,7 @@ PyObject *py_ped_alignment_align_down(PyObject *s, PyObject *args) {
         return NULL;
     }
 
-    return PyLong_FromLong(ret);
+    return PyLong_FromLongLong(ret);
 }
 
 PyObject *py_ped_alignment_align_nearest(PyObject *s, PyObject *args) {
@@ -316,7 +316,7 @@ PyObject *py_ped_alignment_align_nearest(PyObject *s, PyObject *args) {
         return NULL;
     }
 
-    return PyLong_FromLong(ret);
+    return PyLong_FromLongLong(ret);
 }
 
 PyObject *py_ped_alignment_is_aligned(PyObject *s, PyObject *args) {
